==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/ComplianceHistoryFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ComplianceHistoryFluent<A extends ComplianceHistoryFluent<A>> extends BaseFluent<A>{
  public ComplianceHistoryFluent() {
  }
  public ComplianceHistoryFluent(ComplianceHistory instance) {
    instance = (instance != null ? instance : new ComplianceHistory());

    if (instance != null) {
      this.withEventName(instance.getEventName());
      this.withLastTimestamp(instance.getLastTimestamp());
      this.withMessage(instance.getMessage());
      this.withEventName(instance.getEventName());
      this.withLastTimestamp(instance.getLastTimestamp());
      this.withMessage(instance.getMessage());
    }
  }
  private String eventName;
  private String lastTimestamp;
  private String message;
  public String getEventName() {
    return this.eventName;
  }
  public A withEventName(String eventName) {
    this.eventName=eventName; return (A) this;
  }
  public boolean hasEventName() {
    return this.eventName != null;
  }
  public String getLastTimestamp() {
    return this.lastTimestamp;
  }
  public A withLastTimestamp(String lastTimestamp) {
    this.lastTimestamp=lastTimestamp; return (A) this;
  }
  public boolean hasLastTimestamp() {
    return this.lastTimestamp != null;
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public boolean hasMessage() {
    return this.message != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComplianceHistoryFluent that = (ComplianceHistoryFluent) o;
    if (!java.util.Objects.equals(eventName, that.eventName)) return false;

    if (!java.util.Objects.equals(lastTimestamp, that.lastTimestamp)) return false;

    if (!java.util.Objects.equals(message, that.message)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(eventName,  lastTimestamp,  message,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (eventName != null) { sb.append("eventName:"); sb.append(eventName + ","); }
    if (lastTimestamp != null) { sb.append("lastTimestamp:"); sb.append(lastTimestamp + ","); }
    if (message != null) { sb.append("message:"); sb.append(message); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-policy-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/ComplianceHistoryFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ComplianceHistoryFluent<A extends ComplianceHistoryFluent<A>> extends BaseFluent<A>{
  public ComplianceHistoryFluent() {
  }
  
  public ComplianceHistoryFluent(ComplianceHistory instance) {
    this.copyInstance(instance);
  }
  private String eventName;
  private String lastTimestamp;
  private String message;
  
  protected void copyInstance(ComplianceHistory instance) {
    instance = (instance != null ? instance : new ComplianceHistory());
  
    if (instance != null) {
        this.withEventName(instance.getEventName());
        this.withLastTimestamp(instance.getLastTimestamp());
        this.withMessage(instance.getMessage());
        this.withEventName(instance.getEventName());
        this.withLastTimestamp(instance.getLastTimestamp());
        this.withMessage(instance.getMessage());
      }
  }
  
  public String getEventName() {
    return this.eventName;
  }
  
  public A withEventName(String eventName) {
    this.eventName=eventName; return (A) this;
  }
  
  public boolean hasEventName() {
    return this.eventName != null;
  }
  
  public String getLastTimestamp() {
    return this.lastTimestamp;
  }
  
  public A withLastTimestamp(String lastTimestamp) {
    this.lastTimestamp=lastTimestamp; return (A) this;
  }
  
  public boolean hasLastTimestamp() {
    return this.lastTimestamp != null;
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComplianceHistoryFluent that = (ComplianceHistoryFluent) o;
    if (!java.util.Objects.equals(eventName, that.eventName)) return false;
  
    if (!java.util.Objects.equals(lastTimestamp, that.lastTimestamp)) return false;
  
    if (!java.util.Objects.equals(message, that.message)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(eventName,  lastTimestamp,  message,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (eventName != null) { sb.append("eventName:"); sb.append(eventName + ","); }
    if (lastTimestamp != null) { sb.append("lastTimestamp:"); sb.append(lastTimestamp + ","); }
    if (message != null) { sb.append("message:"); sb.append(message); }
    sb.append("}");
    return sb.toString();
  }
  

}
